<?php
/*

Sublime Text 3 Build System for Remote Testing

*/

// Path to gdrbridge
define('GDRBRIDGE','"D:\Program Files (x86)\Gideros\Tools\gdrbridge.exe"');

// IP of the remote device
define('REMOTEIP','192.168.1.220');

// Optional: path and filename of a project file, or false to use the first .gproj file in the project directory
define('PROJECTFILE',false);

define('DEBUG',false);
define('UTIME',200000);

// Get Project File
if(!PROJECTFILE) {
	$pdir = $argv[1];
	if ($handle = opendir($pdir)) {
	    while (false !== ($file = readdir($handle))) {
	    	if(preg_match("#.*\.gproj$#Ui", $file, $m)) {
	    		$pfile = $pdir."\\".$m[0];
	    		break;
	    	}
	    }
	    closedir($handle);
	}
	else {
		debugOut ("ERROR: Can't Read Project Directory: $pdir");
		die();
	}
}
else {
	$pfile = PROJECTFILE;
}

function debugOut($text) {
	$text = str_replace("\n", "\n[".date("Y-m-d H:i:s")."] ", trim($text));
    echo "[".date("Y-m-d H:i:s")."] ".$text."\n";
}

function runCommand($command) {
	ob_start();
	passthru($command,$error);
	$var = ob_get_contents();
	ob_end_clean();
	if (DEBUG) debugOut($command." -- Error: ".$error." Output: ".$var);
	return array("error" => $error, "output" => $var);	
}

debugOut ("Starting Gideros with Project File: $pfile");

runCommand(GDRBRIDGE." setip ".REMOTEIP);

$ret = array("output" => 0);
while ($ret["output"] != 1) {
	usleep(UTIME);
	$ret = runCommand(GDRBRIDGE." isconnected");
}

runCommand(GDRBRIDGE." play ".$pfile);

usleep(UTIME);

$ended = false;
debugOut("Waiting for Remote Output:");
while (!$ended) {
	ob_start();
	passthru(GDRBRIDGE." getlog",$error);
	$var = ob_get_contents();
	ob_end_clean();
	if (preg_match("#.*---END---.*#Ui", $var, $m)) {
		debugOut($var);
		$ended = true;
	}
	elseif (preg_match("#(.*\.lua):([0-9]+):.*$#Ui", $var, $m)) {
		debugOut('!ERROR -- File:"'.trim($m[1]).'", Line:'.trim($m[2]));
		debugOut($var);
		$ended = true;
	}
	else {
		if (strlen($var)>1) debugOut($var);
		usleep(UTIME);
	}
}
debugOut("FINISHED");
?>